gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r8852 - GNUnet/src/include


From: gnunet
Subject: [GNUnet-SVN] r8852 - GNUnet/src/include
Date: Tue, 25 Aug 2009 12:54:48 -0600

Author: nevans
Date: 2009-08-25 12:54:47 -0600 (Tue, 25 Aug 2009)
New Revision: 8852

Modified:
   GNUnet/src/include/dv.h
   GNUnet/src/include/gnunet_dhtlog_service.h
Log:
headers for changed sql and dv stuffs

Modified: GNUnet/src/include/dv.h
===================================================================
--- GNUnet/src/include/dv.h     2009-08-25 18:53:40 UTC (rev 8851)
+++ GNUnet/src/include/dv.h     2009-08-25 18:54:47 UTC (rev 8852)
@@ -32,9 +32,24 @@
 #define GNUNET_DV_LEAST_COST 1
 #define GNUNET_DV_MAX_COST -1
 #define GNUNET_DV_MAX_TABLE_SIZE -1
-#define GNUNET_DV_DEFAULT_SEND_INTERVAL 10000
-#define GNUNET_DV_PEER_EXPIRATION_TIME 600 * GNUNET_CRON_SECONDS
-#define GNUNET_DV_MAINTAIN_FREQUENCY 60 * GNUNET_CRON_SECONDS
+
+/*
+ * How often do we send out peer information?
+ */
+#define GNUNET_DV_DEFAULT_SEND_INTERVAL 500 * GNUNET_CRON_MILLISECONDS
+
+#define GNUNET_DV_MAX_SEND_INTERVAL 5000 * GNUNET_CRON_MILLISECONDS
+/*
+ * How long can we have not heard from a peer and
+ * still have it in our tables?
+ */
+#define GNUNET_DV_PEER_EXPIRATION_TIME 3000 * GNUNET_CRON_SECONDS
+
+/*
+ * How often should we check if expiration time has elapsed?
+ */
+#define GNUNET_DV_MAINTAIN_FREQUENCY 30 * GNUNET_CRON_SECONDS
+
 #define GNUNET_DV_DHT_GOSSIP_PRIORITY GNUNET_EXTREME_PRIORITY / 10
 
 /**

Modified: GNUnet/src/include/gnunet_dhtlog_service.h
===================================================================
--- GNUnet/src/include/gnunet_dhtlog_service.h  2009-08-25 18:53:40 UTC (rev 
8851)
+++ GNUnet/src/include/gnunet_dhtlog_service.h  2009-08-25 18:54:47 UTC (rev 
8852)
@@ -88,9 +88,11 @@
                        char *message);
 
   /*
    * Update the trial information with the ending time
stats
    */
-  int (*update_trial) (unsigned long long trialuid);
+  int (*update_trial) (unsigned long long trialuid,
+                       unsigned long long totalMessagesDropped,
+                       unsigned long long totalBytesDropped);
 
   /*
    * Update the trial information with the total connections
@@ -88,9 +88,11 @@
 
   /*
-   * Update the trial information with the ending time
+   * Update the trial information with the ending time and dropped message 
stats
    */





reply via email to

[Prev in Thread] Current Thread [Next in Thread]